import React, { useState } from 'react';
import ShipmentPanel from '../components/ShipmentPanel';
import ShipmentForm from '../components/ShipmentForm'; // Import the ShipmentForm component
import { Shipment, ContactPerson, Proposal, Address } from '../types'; // Ensure these types are defined

const ShipmentView: React.FC = () => {
    const [isCreatingShipment, setIsCreatingShipment] = useState(false); // State to track if the form is open
    const [newShipment, setNewShipment] = useState<Shipment>({
        shipment_id: '',
        shipment_name: '',
        shipment_status: '',
        number_of_dewars: 0,
        shipment_date: '',
        contact_person: null,
        dewars: [],
        return_address: [],
        proposal_number: undefined,
        comments: '',
    });

    // Dummy data for contact persons, proposals, and addresses
    const contactPersons: ContactPerson[] = [
        // Populate with contact person objects
    ];
    const proposals: Proposal[] = [
        // Populate with proposal objects
    ];
    const returnAddresses: Address[] = [
        // Populate with return address objects
    ];

    const selectShipment = (shipment: Shipment | null) => {
        console.log('Selected Shipment:', shipment);
        // Additional logic for selected shipment
    };

    const handleSaveShipment = () => {
        console.log('Saving shipment:', newShipment);
        setIsCreatingShipment(false); // Close the form after saving
        // Add logic to save the shipment
    };

    return (
        <div style={{ display: 'flex', padding: '16px' }}>
            {/* Shipment Panel on the left side */}
            <ShipmentPanel
                selectedPage="shipments"
                setIsCreatingShipment={setIsCreatingShipment} // Pass the state setter
                selectShipment={selectShipment}
                sx={{ width: '300px' }} // Adjust width as needed
            />
            {/* Conditional rendering of the ShipmentForm */}
            <div style={{ marginLeft: '16px', flexGrow: 1 }}>
                {isCreatingShipment ? (
                    <ShipmentForm
                        newShipment={newShipment}
                        setNewShipment={setNewShipment}
                        handleSaveShipment={handleSaveShipment}
                        contactPersons={contactPersons}
                        proposals={proposals}
                        returnAddresses={returnAddresses}
                    />
                ) : (
                    <div> {/* Content when form is not open */} </div>
                )}
            </div>
        </div>
    );
};

export default ShipmentView;
